==> kubernetes-model-gatewayapi-6.4.1-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/GatewayClassSpecFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface GatewayClassSpecFluent<A extends GatewayClassSpecFluent<A>> extends Fluent<A>{
  public String getControllerName();
  public A withControllerName(String controllerName);
  public Boolean hasControllerName();
  public String getDescription();
  public A withDescription(String description);
  public Boolean hasDescription();
  
  /**
   * This method has been deprecated, please use method buildParametersRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public ParametersReference getParametersRef();
  public ParametersReference buildParametersRef();
  public A withParametersRef(ParametersReference parametersRef);
  public Boolean hasParametersRef();
  public A withNewParametersRef(String group,String kind,String name,String namespace);
  public GatewayClassSpecFluent.ParametersRefNested<A> withNewParametersRef();
  public GatewayClassSpecFluent.ParametersRefNested<A> withNewParametersRefLike(ParametersReference item);
  public GatewayClassSpecFluent.ParametersRefNested<A> editParametersRef();
  public GatewayClassSpecFluent.ParametersRefNested<A> editOrNewParametersRef();
  public GatewayClassSpecFluent.ParametersRefNested<A> editOrNewParametersRefLike(ParametersReference item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ParametersRefNested<N> extends Nested<N>,ParametersReferenceFluent<GatewayClassSpecFluent.ParametersRefNested<N>>{
    public N and();
    public N endParametersRef();
    
  }
  
}

==> kubernetes-model-gatewayapi-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/GatewayClassSpecFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface GatewayClassSpecFluent<A extends GatewayClassSpecFluent<A>> extends Fluent<A>{
  public String getControllerName();
  public A withControllerName(String controllerName);
  public Boolean hasControllerName();
  public String getDescription();
  public A withDescription(String description);
  public Boolean hasDescription();
  
  /**
   * This method has been deprecated, please use method buildParametersRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public ParametersReference getParametersRef();
  public ParametersReference buildParametersRef();
  public A withParametersRef(ParametersReference parametersRef);
  public Boolean hasParametersRef();
  public A withNewParametersRef(String group,String kind,String name,String namespace);
  public GatewayClassSpecFluent.ParametersRefNested<A> withNewParametersRef();
  public GatewayClassSpecFluent.ParametersRefNested<A> withNewParametersRefLike(ParametersReference item);
  public GatewayClassSpecFluent.ParametersRefNested<A> editParametersRef();
  public GatewayClassSpecFluent.ParametersRefNested<A> editOrNewParametersRef();
  public GatewayClassSpecFluent.ParametersRefNested<A> editOrNewParametersRefLike(ParametersReference item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ParametersRefNested<N> extends Nested<N>,ParametersReferenceFluent<GatewayClassSpecFluent.ParametersRefNested<N>>{
    public N and();
    public N endParametersRef();
    
  }
  
}
